@@ -31,7 +31,7 @@ def load_model_wrapper(args):
     # read .h5 model
     custom_objects={"multinomial_nll": losses.multinomial_nll, "tf": tf}    
     get_custom_objects().update(custom_objects)    
-    model=load_model(args.model_h5)
+    model=load_model(args.model_h5,compile=False)
     print("got the model")
     model.summary()
     return model
